1. A little history... — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Introduction to CubicWeb »

# 1. A little history...

CubicWeb is a semantic web application framework that Logilab started developing in 2001 as an offspring of its Narval research project. CubicWeb is written in Python and includes a data server and a web engine.

Its data server publishes data federated from different sources like SQL databases, LDAP directories, VCS repositories or even from other CubicWeb data servers.

Its web engine was designed to let the final user control what content to select and how to display it. It allows one to browse the federated data sources and display the results with the rendering that best fits the context. This flexibility of the user interface gives back to the user some capabilities usually only accessible to application developers.

CubicWeb has been developed by Logilab and used in-house for many years before it was first installed for its clients in 2006 as version 2.

In 2008, CubicWeb version 3 became downloadable for free under the terms of the LGPL license. Its community is now steadily growing without hampering the fast-paced stream of changes thanks to the time and energy originally put in the design of the framework.

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Introduction to CubicWeb »